##Each number (1-1 to 3-3) of the analysis corresponds to Table S3##


library(vegan)
library(lme4)
library(car)
library(lsmeans)
library(multcomp)
library(adespatial)


#1-1 vegetation: species diversity and plant coverage
d<-read.csv("speciesdiversity.csv")
model_sp<-glm(species~year,data=d,family=poisson)
model_di<-glm(shannon~year,data=d)
Anova(model, type=2, test.statistic=c("LR"))#for each model#
summary(glht(model,lsm(pairwise~year)))


#1-2 vegetation PERMANOVA analyses#
#plant coverage#

data <- read.csv("plant_site.csv")
data1<-data[,6:275]
data1.h <- decostand(data1, "hel")
geo<-data[,4:5]
adonis(data1 ~ year, data = data, method="bray",permutation=10000)

#taking into account for spatial autocorrelation#

dbmem.tmp <- dbmem(geo, silent = FALSE)
dbmem <- as.data.frame(dbmem.tmp)
attributes(dbmem.tmp)$values

data1.det <- resid(lm(as.matrix(data1.h) ~ ., data = geo))
dbmem.rda <- rda(data1.det ~., dbmem)
anova(dbmem.rda)#not significant
R2a <- RsquareAdj(dbmem.rda)$adj.r.squared
dbmem.fwd <- forward.sel(data1.det, as.matrix(dbmem),adjR2thresh = R2a)#Error ocurred because no variables were selected significant. 


#1-3 sum of vegetation coverage#
d_cv<-read.csv("coverage.csv")
model_cv<-glmer(coverage~year+(1|study_year:site),data=d_cv,family=poisson)
Anova(model_cv, type=2, test.statistic=c("Chi"))
summary(glht(model,lsm(pairwise~year)))

#1-4 sum of vegetation coverage per life from and plant architecture#
model<-glmer(annual~year+(1|site),data=d_cv,family="poisson")#replace "annual" with other life form and plant architecture
Anova(model, type=2, test.statistic=c("Chi"))
summary(glht(model,lsm(pairwise ~ year)))

#1-5 vegetation PWERMANOVA2
data <- read.csv("coverage_58sp.csv")
data1<-data[,3:6]
adonis(formula = data1 ~ lifeform, data = data, permutations = 10000, method = "bray")
data <- read.csv("coverage_30sp.csv")
data1<-data[,4:7]
adonis(formula = data1 ~ plant_architecture, data = data, permutations = 10000, method = "bray")
#1-6 vegetation k-means
ckm<-kmeanspp(decostand(data1,"hell"),k=2)


# 2-1 relationship between plant coverage and feeding trace (MDG)#
data <- read.csv("coverage_mdg.csv")
data$sqrtmdg<-sqrt(data$mdg)
model<-lmer(sqrtmdg~coverage+(1|survey_year:site),data=data)
Anova(model, type=2, test.statistic=c("Chi"))

#2-2 MDG PERMANOVA
datam<-read.csv("mdg_NMDS.csv")
datam1<-datam[,4:7]
adonis(datam1 ~ lifeform, data = datam, permutations = 10000, method="bray")
datah<-subset(datam,plant_architecture=="rosset_seasonal"|plant_architecture=="prostrate"|plant_architecture=="erect")
datah1<-datah[,4:7]
adonis(datah1 ~ plant_architecture, data = datah, permutations = 10000, method="bray")

#2-3 MDG kmeans
ckm<-kmeanspp(decostand(datam1,"hell"),k=3)


#3-1 DNA barcoding PERMANOVA#
data<-read.csv("DNA_NMDS_rate.csv")
data1<-data[,19:116]
dataf<-data[,2:5]
dataf$year <- as.factor(dataf$year)
adonis(data1 ~ year, data = dataf, strata=dataf$site, method="bray",permutation=10000)

#taking into account for spatial autocorrelation#

dbmem.tmp <- dbmem(geo, silent = FALSE)
dbmem <- as.data.frame(dbmem.tmp)
attributes(dbmem.tmp)$values

data1.det <- resid(lm(as.matrix(data1) ~ ., data = geo))
dbmem.rda <- rda(data1.det ~., dbmem)
anova(dbmem.rda)#not significant
R2a <- RsquareAdj(dbmem.rda)$adj.r.squared
dbmem.fwd <- forward.sel(data1.det, as.matrix(dbmem),adjR2thresh = R2a)#Error ocurred because no variables were selected significant. 

#3-2 DNA barcoding per life from and plant architecture
model<-lmer(sqrt(data$annual/data$all)~year+(1|sample_year:site),data=data)
Anova(model, type=2, test.statistic=c("Chi"))#replace "annual" with other life form and plant architecture
summary(glht(model, lsm(pairwise ~ year)))



#3-3 DNA barcoding PERMANOVA2 #
data<-read.csv("DNA_NMDS2_rate.csv")
data1<-data[,4:7]
dataf<-data[,2:3]
adonis(data1 ~ lifeform,data=dataf,method="bray",permutation=10000)
datah<-subset(data,plant_architecture=="rosset_seasonal"|plant_architecture=="prostrate"|plant_architecture=="erect")
datah1<-datah[,4:7]
adonis(datah1 ~ plant_architecture, data = datah,method="bray",permutation=10000)

#3-3 DNA kmeans
ckm<-kmeanspp(decostand(data1,"hell"),k=3)


